@@ -13,11 +13,13 @@ typedef enum cffi_enumdocumented
     {
     CFFI_A = 0,
     CFFI_B = 1,
+    CFFI_C = 2,
     } cffi_enumdocumented;
 
 typedef struct cffi_context cffi_context;
 typedef struct cffi_generic2u8 cffi_generic2u8;
 typedef struct cffi_generic3 cffi_generic3;
+typedef struct cffi_generic4 cffi_generic4;
 typedef struct cffi_opaque cffi_opaque;
 typedef struct cffi_simpleservice cffi_simpleservice;
 typedef struct cffi_empty cffi_empty;
@@ -30,6 +32,11 @@ typedef enum cffi_ffierror
     CFFI_FAIL = 300,
     } cffi_ffierror;
 
+typedef struct cffi_extratypef32
+    {
+    float x;
+    } cffi_extratypef32;
+
 typedef struct cffi_inner
     {
     float x;
@@ -85,6 +92,23 @@ typedef struct cffi_vec3f32
     float z;
     } cffi_vec3f32;
 
+typedef struct cffi_visibility1
+    {
+    uint8_t pblc;
+    uint8_t prvt;
+    } cffi_visibility1;
+
+typedef struct cffi_visibility2
+    {
+    uint8_t pblc1;
+    uint8_t pblc2;
+    } cffi_visibility2;
+
+typedef struct cffi_weird1u32
+    {
+    uint32_t x;
+    } cffi_weird1u32;
+
 typedef uint8_t (*cffi_fptr_fn_u8_rval_u8)(uint8_t x0);
 
 typedef uint32_t (*cffi_fptr_fn_u32_rval_u32)(uint32_t x0);
@@ -104,6 +128,13 @@ typedef struct cffi_genericu8
     uint8_t* x;
     } cffi_genericu8;
 
+typedef struct cffi_weird2u8
+    {
+    uint8_t t;
+    uint8_t a[5];
+    uint8_t* r;
+    } cffi_weird2u8;
+
 typedef cffi_tupled (*cffi_fptr_fn_Tupled_rval_Tupled)(cffi_tupled x0);
 
 typedef bool (*cffi_fptr_fn_pmut_i64_rval_bool)(int64_t* x0);
@@ -175,10 +206,11 @@ cffi_tupled tupled(cffi_tupled x);
 cffi_ffierror complex_args_1(cffi_vec3f32 _a, cffi_empty* _b);
 cffi_opaque* complex_args_2(cffi_someforeigntype _cmplx);
 uint8_t callback(cffi_fptr_fn_u8_rval_u8 callback, uint8_t value);
-uint32_t generic_1(cffi_genericu32 x, cffi_phantomu8 _y);
-uint8_t generic_2(cffi_genericu8 x, cffi_phantomu8 _y);
-uint8_t generic_3(cffi_generic2u8* x);
-uint8_t generic_4(cffi_generic3* x);
+uint32_t generic_1a(cffi_genericu32 x, cffi_phantomu8 _y);
+uint8_t generic_1b(cffi_genericu8 x, cffi_phantomu8 _y);
+uint8_t generic_2(cffi_generic2u8* x);
+uint8_t generic_3(cffi_generic3* x);
+uint8_t generic_4(cffi_generic4* x);
 uint8_t array_1(cffi_array x);
 cffi_enumdocumented documented(cffi_structdocumented _x);
 cffi_vec1 ambiguous_1(cffi_vec1 x);
@@ -187,6 +219,8 @@ bool ambiguous_3(cffi_vec1 x, cffi_vec2 y);
 cffi_vec namespaced_type(cffi_vec x);
 cffi_ffierror panics();
 void sleep(uint64_t millis);
+bool weird_1(cffi_weird1u32 _x, cffi_weird2u8 _y);
+void visibility(cffi_visibility1 _x, cffi_visibility2 _y);
 uint32_t pattern_ascii_pointer_1(uint8_t* x);
 uint32_t pattern_ascii_pointer_len(uint8_t* x, cffi_useasciistringpattern y);
 uint32_t pattern_ffi_slice_1(cffi_ffisliceu32 ffi_slice);
@@ -197,7 +231,8 @@ cffi_vec3f32 pattern_ffi_slice_delegate_huge(cffi_fptr_fn_FFISliceVec3f32_rval_V
 cffi_ffioptioninner pattern_ffi_option_1(cffi_ffioptioninner ffi_slice);
 cffi_inner pattern_ffi_option_2(cffi_ffioptioninner ffi_slice);
 uint8_t pattern_ffi_bool(uint8_t ffi_bool);
-void my_api_init_v1(cffi_myapiv1* api);
+void pattern_my_api_init_v1(cffi_myapiv1* api);
+uint64_t pattern_api_guard();
 uint32_t pattern_callback_1(cffi_fptr_fn_u32_rval_u32 callback, uint32_t x);
 cffi_ffierror pattern_service_create(cffi_context** context_ptr, uint32_t value);
 cffi_ffierror pattern_service_destroy(cffi_context** context_ptr);
@@ -243,6 +278,7 @@ class EnumDocumented:
     """Documented enum."""
     A = 0
     B = 1
+    C = 2
 
 
 class Array(object):
@@ -281,6 +317,29 @@ class Empty(object):
     def ptr(self):
         return self._ctx
 
+class ExtraTypef32(object):
+    """"""
+    def __init__(self):
+        global _api, ffi
+        self._ctx = ffi.new("cffi_extratypef32[]", 1)
+
+    def array(n):
+        global _api, ffi
+        return ffi.new("cffi_extratypef32[]", n)
+
+    def ptr(self):
+        return self._ctx
+
+    @property
+    def x(self):
+        """"""
+        return self._ctx[0].x
+
+    @x.setter
+    def x(self, value):
+        self._ptr_x = value
+        self._ctx[0].x = value
+
 class Genericu32(object):
     """"""
     def __init__(self):
@@ -640,6 +699,138 @@ class Vec3f32(object):
         self._ptr_z = value
         self._ctx[0].z = value
 
+class Visibility1(object):
+    """"""
+    def __init__(self):
+        global _api, ffi
+        self._ctx = ffi.new("cffi_visibility1[]", 1)
+
+    def array(n):
+        global _api, ffi
+        return ffi.new("cffi_visibility1[]", n)
+
+    def ptr(self):
+        return self._ctx
+
+    @property
+    def pblc(self):
+        """"""
+        return self._ctx[0].pblc
+
+    @pblc.setter
+    def pblc(self, value):
+        self._ptr_pblc = value
+        self._ctx[0].pblc = value
+
+    @property
+    def prvt(self):
+        """"""
+        return self._ctx[0].prvt
+
+    @prvt.setter
+    def prvt(self, value):
+        self._ptr_prvt = value
+        self._ctx[0].prvt = value
+
+class Visibility2(object):
+    """"""
+    def __init__(self):
+        global _api, ffi
+        self._ctx = ffi.new("cffi_visibility2[]", 1)
+
+    def array(n):
+        global _api, ffi
+        return ffi.new("cffi_visibility2[]", n)
+
+    def ptr(self):
+        return self._ctx
+
+    @property
+    def pblc1(self):
+        """"""
+        return self._ctx[0].pblc1
+
+    @pblc1.setter
+    def pblc1(self, value):
+        self._ptr_pblc1 = value
+        self._ctx[0].pblc1 = value
+
+    @property
+    def pblc2(self):
+        """"""
+        return self._ctx[0].pblc2
+
+    @pblc2.setter
+    def pblc2(self, value):
+        self._ptr_pblc2 = value
+        self._ctx[0].pblc2 = value
+
+class Weird1u32(object):
+    """"""
+    def __init__(self):
+        global _api, ffi
+        self._ctx = ffi.new("cffi_weird1u32[]", 1)
+
+    def array(n):
+        global _api, ffi
+        return ffi.new("cffi_weird1u32[]", n)
+
+    def ptr(self):
+        return self._ctx
+
+    @property
+    def x(self):
+        """"""
+        return self._ctx[0].x
+
+    @x.setter
+    def x(self, value):
+        self._ptr_x = value
+        self._ctx[0].x = value
+
+class Weird2u8(object):
+    """"""
+    def __init__(self):
+        global _api, ffi
+        self._ctx = ffi.new("cffi_weird2u8[]", 1)
+
+    def array(n):
+        global _api, ffi
+        return ffi.new("cffi_weird2u8[]", n)
+
+    def ptr(self):
+        return self._ctx
+
+    @property
+    def t(self):
+        """"""
+        return self._ctx[0].t
+
+    @t.setter
+    def t(self, value):
+        self._ptr_t = value
+        self._ctx[0].t = value
+
+    @property
+    def a(self):
+        """"""
+        return self._ctx[0].a
+
+    @a.setter
+    def a(self, value):
+        self._ptr_a = value
+        self._ctx[0].a = value
+
+    @property
+    def r(self):
+        """"""
+        return self._ctx[0].r
+
+    @r.setter
+    def r(self, value):
+        self._ptr_r = value
+        self._ctx[0].r = value
+
 class FFIError:
     """"""
     Ok = 0
@@ -861,23 +1052,30 @@ Parameter x must point to valid data."""
             value = value._ctx[0]
         return _api.callback(callback, value)
 
-    def generic_1(x, _y):
+    def generic_1a(x, _y):
         """"""
         global _api
         if hasattr(x, "_ctx"):
             x = x._ctx[0]
         if hasattr(_y, "_ctx"):
             _y = _y._ctx[0]
-        return _api.generic_1(x, _y)
+        return _api.generic_1a(x, _y)
 
-    def generic_2(x, _y):
+    def generic_1b(x, _y):
         """"""
         global _api
         if hasattr(x, "_ctx"):
             x = x._ctx[0]
         if hasattr(_y, "_ctx"):
             _y = _y._ctx[0]
-        return _api.generic_2(x, _y)
+        return _api.generic_1b(x, _y)
+
+    def generic_2(x):
+        """"""
+        global _api
+        if hasattr(x, "_ctx"):
+            x = x._ctx[0]
+        return _api.generic_2(x)
 
     def generic_3(x):
         """"""
@@ -949,6 +1147,24 @@ Parameter x must point to valid data."""
             millis = millis._ctx[0]
         return _api.sleep(millis)
 
+    def weird_1(_x, _y):
+        """"""
+        global _api
+        if hasattr(_x, "_ctx"):
+            _x = _x._ctx[0]
+        if hasattr(_y, "_ctx"):
+            _y = _y._ctx[0]
+        return _api.weird_1(_x, _y)
+
+    def visibility(_x, _y):
+        """"""
+        global _api
+        if hasattr(_x, "_ctx"):
+            _x = _x._ctx[0]
+        if hasattr(_y, "_ctx"):
+            _y = _y._ctx[0]
+        return _api.visibility(_x, _y)
+
     def pattern_ascii_pointer_1(x):
         """"""
         global _api
@@ -1025,12 +1241,17 @@ Parameter x must point to valid data."""
             ffi_bool = ffi_bool._ctx[0]
         return _api.pattern_ffi_bool(ffi_bool)
 
-    def my_api_init_v1(api):
+    def pattern_my_api_init_v1(api):
         """"""
         global _api
         if hasattr(api, "_ctx"):
             api = api._ctx[0]
-        return _api.my_api_init_v1(api)
+        return _api.pattern_my_api_init_v1(api)
+
+    def pattern_api_guard():
+        """"""
+        global _api
+        return _api.pattern_api_guard()
 
     def pattern_callback_1(callback, x):
         """"""
